==> ah-formbuilder-1.0.53.tgz: package/es/components/toolbar/field-forms/File.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";
var _jsxFileName = "/home/ayesha/Project/formbuilder/src/components/toolbar/field-forms/File.js";

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import SimpleTabs from "../../../utils/Tabs/SimpleTabs";
import TextInput from "../../../utils/inputs/TextInput";
import Checkbox from "../../../utils/checkboxs/Checkbox";
import ValidateField from "../../../utils/validations/ValidateField";
import Button from "@material-ui/core/Button";
import { disableFieldEdit as _disableFieldEdit } from "../../../actions/toolbarActions";
import { createField as _createField, deleteField as _deleteField, deleteNewField as _deleteNewField, updateField as _updateField } from '../../../actions/formActions';
import { connect } from "react-redux";
import SearchableSelect from "../../../utils/selects/SearchableSelect";
import MultiSelect from "../../../utils/selects/MultiSelect";
import { InputLabel } from '@material-ui/core';
import RichTextEditor from '../../../utils/rich-text-editor';
import { Scrollbars } from 'react-custom-scrollbars';
import ConditionalLogic from '../../../utils/conditional-logic';
import { getHeight } from '../../../utils/helpers';
import { processLocalFields } from './utils/helpers';
import FieldRenderer from './utils/FieldRenderer';
import axios from "axios";
import { selectFieldsConfigs } from './utils/selectFieldConfigs';
var basicTabTitle = {
  en: 'Basic Settings',
  ar: 'الإعدادات الأساسية'
};
var advanceTabTitle = {
  en: 'Advance Settings',
  ar: 'إعدادات متقدمة'
};
var machineNameLabel = {
  en: 'Machine Name/Field ID',
  ar: 'إسم الألة'
};
var visibilityLabel = {
  en: 'Visibility to Employee',
  ar: 'الرؤية للموظف'
};
var cancelLabel = {
  en: 'Cancel',
  ar: 'إلغاء'
};
var saveLabel = {
  en: 'Save',
  ar: 'حفظ'
};
var fileTypeLabel = {
  en: 'Supported File Types',
  ar: 'أنواع الملفات المدعومة'
};
var allowMultpleFilesLabel = {
  en: 'Allow Uploading Multiple Files',
  ar: 'تسمح بتحميل ملفات متعددة'
};
var visibleLabel = {
  en: 'Visible',
  ar: 'مرئي'
};
var hiddenLabel = {
  en: 'Hidden',
  ar: 'مختفي'
};
var supportedFileTypes = [{
  label: 'Images',
  value: 'images'
}, {
  label: 'PDF',
  value: 'pdf'
}, {
  label: 'Word Document',
  value: 'word'
}, {
  label: 'Video',
  value: 'video'
}, {
  label: 'Excel Sheet',
  value: 'excel'
}, {
  label: 'Presentation',
  value: 'presentation'
}];

var Select = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(Select, _React$Component);

  function Select(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_this), "handleTabChange", function (e, newValue) {
      _this.setState({
        activeTab: newValue
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleDataChange", function (val, name) {
      var _this$setState;

      _this.setState((_this$setState = {}, _this$setState[name] = val, _this$setState.errors = {}, _this$setState));
    });

    _defineProperty(_assertThisInitialized(_this), "saveField", function () {
      _this.setState(_extends({}, _this.state, {
        isSaving: true
      }));

      var _this$state = _this.state,
          name = _this$state.name,
          machineName = _this$state.machineName,
          order = _this$state.order,
          conditionalLogic = _this$state.conditionalLogic,
          isRequired = _this$state.isRequired,
          placeholder = _this$state.placeholder,
          helpText = _this$state.helpText,
          subType = _this$state.subType,
          visibility = _this$state.visibility,
          uuid = _this$state.uuid,
          type = _this$state.type,
          isMultiple = _this$state.isMultiple,
          supportedFiles = _this$state.supportedFiles,
          parentId = _this$state.parentId;
      var newField = {
        name: name,
        machineName: machineName,
        order: order,
        uuid: uuid,
        type: type,
        parentId: parentId,
        config: {
          conditionalLogic: conditionalLogic,
          isConditionalEnabled: !!conditionalLogic.conditions.length,
          isRequired: isRequired,
          placeholder: placeholder,
          helpText: helpText,
          subType: subType,
          visibility: visibility,
          isMultiple: isMultiple,
          supportedFiles: supportedFiles
        }
      };
      var data = {
        field: newField
      };
      newField.locals = processLocalFields(_this.props.locals, _this.state);
      data.locals = processLocalFields(_this.props.locals, _this.state);
      ValidateField(newField, null, _this.props.currentLang).then( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _this.props.updateField(newField);

                _context.next = 3;
                return axios.post(_this.props.predefinedEndpoint + "/form/field/" + _this.props.formId, data);

              case 3:
                _this.props.disableFieldEdit();

                _this.setState(_extends({}, _this.state, {
                  isSaving: false
                }));

              case 5:
              case "end":
                return _context.stop();
            }
          }
        }, _callee);
      })))["catch"](function (errors) {
        var keys = Object.keys(errors);

        if (keys[0] === 'machineName' || keys[0] === 'conditionalLogic') {
          _this.handleTabChange({}, 'advance');
        } else {
          _this.handleTabChange({}, 'basic');
        }

        _this.setState({
          errors: errors,
          isSaving: false
        });
      });
    });

    _defineProperty(_assertThisInitialized(_this), "cancelEdit", function () {
      _this.props.deleteNewField();

      _this.props.disableFieldEdit();
    });

    _defineProperty(_assertThisInitialized(_this), "updateChoices", function (choices) {
      _this.setState({
        choices: choices
      });
    });

    _defineProperty(_assertThisInitialized(_this), "renderTabFields", function () {
      if (_this.state.activeTab === 'basic') {
        return /*#__PURE__*/React.createElement("div", {
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 171,
            columnNumber: 9
          }
        }, /*#__PURE__*/React.createElement(FieldRenderer, _extends({}, _this.state, {
          locals: _this.props.locals,
          fieldConfigs: selectFieldsConfigs,
          handleDataChange: _this.handleDataChange,
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 172,
            columnNumber: 11
          }
        })), /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 189,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(MultiSelect, {
          label: supportedFileTypes[_this.props.currentLang],
          options: supportedFileTypes,
          value: _this.state.supportedFiles,
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value, 'supportedFiles');
          },
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 190,
            columnNumber: 13
          }
        })), /*#__PURE__*/React.createElement(Checkbox, {
          checked: _this.state.isMultiple,
          handleChange: function handleChange(val) {
            return _this.handleDataChange(val, 'isMultiple');
          },
          label: allowMultpleFilesLabel[_this.props.currentLang],
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 192,
            columnNumber: 11
          }
        }));
      } else {
        return /*#__PURE__*/React.createElement("div", {
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 197,
            columnNumber: 9
          }
        }, /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 198,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(TextInput, {
          value: _this.state.machineName,
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value, 'machineName');
          },
          label: machineNameLabel[_this.props.currentLang],
          required: true,
          autoFocus: true,
          error: _this.state.errors.machineName,
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 199,
            columnNumber: 13
          }
        })), /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4",
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 201,
            columnNumber: 11
          }
        }, /*#__PURE__*/React.createElement(SearchableSelect, {
          options: [{
            label: visibleLabel[_this.props.currentLang],
            value: 'visible'
          }, {
            label: hiddenLabel[_this.props.currentLang],
            value: 'hidden'
          }],
          label: visibilityLabel[_this.props.currentLang],
          value: _this.state.visibility ? 'visible' : 'hidden',
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value === 'visible', 'visibility');
          },
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 202,
            columnNumber: 13
          }
        })), /*#__PURE__*/React.createElement(ConditionalLogic, {
          predefined: _this.props.predefined,
          conditionalLogic: _this.state.conditionalLogic,
          isConditionalEnabled: _this.state.isConditionalEnabled,
          handleChange: _this.handleDataChange,
          errors: _this.state.errors.conditionalLogic ? _this.state.errors.conditionalLogic : [],
          __self: _assertThisInitialized(_this),
          __source: {
            fileName: _jsxFileName,
            lineNumber: 204,
            columnNumber: 11
          }
        }));
      }
    });

    var _choices = [{
      name: 'Choice 1',
      value: 1
    }, {
      name: 'Choice 2',
      value: 2
    }, {
      name: 'Choice 3',
      value: 3
    }];
    _this.state = _extends({
      choices: _choices,
      activeTab: 'basic',
      errors: {},
      uuid: props.data.uuid,
      name: props.data.name,
      type: props.data.type,
      order: props.data.order,
      parentId: props.data.parentId,
      machineName: props.data.machineName,
      isSaving: false
    }, props.data.config);
    return _this;
  }

  var _proto = Select.prototype;

  _proto.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    if (nextProps.data.uuid !== this.state.uuid) {
      var choices = [{
        name: 'Choice 1',
        value: 1
      }, {
        name: 'Choice 2',
        value: 2
      }, {
        name: 'Choice 3',
        value: 3
      }];
      this.setState(_extends({
        choices: choices,
        activeTab: 'basic',
        errors: {},
        uuid: nextProps.data.uuid,
        name: nextProps.data.name,
        type: nextProps.data.type,
        order: nextProps.data.order,
        parentId: nextProps.data.parentId,
        machineName: nextProps.data.machineName,
        isSaving: false
      }, nextProps.data.config));
    }
  };

  _proto.render = function render() {
    return /*#__PURE__*/React.createElement("div", {
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 212,
        columnNumber: 7
      }
    }, /*#__PURE__*/React.createElement(SimpleTabs, {
      value: this.state.activeTab,
      handleChange: this.handleTabChange,
      options: [{
        label: basicTabTitle[this.props.currentLang],
        value: 'basic'
      }, {
        label: advanceTabTitle[this.props.currentLang],
        value: 'advance'
      }],
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 213,
        columnNumber: 9
      }
    }), /*#__PURE__*/React.createElement(Scrollbars, {
      style: {
        height: getHeight(true, true)
      },
      autoHide: true,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 214,
        columnNumber: 9
      }
    }, /*#__PURE__*/React.createElement("div", {
      className: "ahfb-p-3 ahfb-my-3",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 215,
        columnNumber: 11
      }
    }, this.renderTabFields(), /*#__PURE__*/React.createElement("div", {
      className: "ahfb-width-full ahfb-text-right",
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 217,
        columnNumber: 13
      }
    }, /*#__PURE__*/React.createElement(Button, {
      variant: "outlined",
      className: "ahfb-mr-2",
      onClick: this.cancelEdit,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 218,
        columnNumber: 15
      }
    }, cancelLabel[this.props.currentLang]), /*#__PURE__*/React.createElement(Button, {
      variant: "contained",
      disableElevation: true,
      disabled: this.state.isSaving,
      onClick: this.saveField,
      __self: this,
      __source: {
        fileName: _jsxFileName,
        lineNumber: 221,
        columnNumber: 15
      }
    }, saveLabel[this.props.currentLang])))));
  };

  return Select;
}(React.Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    operation: state.toolbar.operation,
    predefined: state.form.predefined,
    locals: state.form.locals,
    formId: state.form.formId,
    predefinedEndpoint: state.form.predefinedEndpoint,
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    disableFieldEdit: function disableFieldEdit() {
      return dispatch(_disableFieldEdit());
    },
    deleteNewField: function deleteNewField() {
      return dispatch(_deleteNewField());
    },
    createField: function createField(data) {
      return dispatch(_createField(data));
    },
    updateField: function updateField(data) {
      return dispatch(_updateField(data));
    },
    deleteField: function deleteField(id) {
      return dispatch(_deleteField(id));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(Select);

==> ah-formbuilder-1.0.61.tgz: package/es/components/toolbar/field-forms/File.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import SimpleTabs from "../../../utils/Tabs/SimpleTabs";
import TextInput from "../../../utils/inputs/TextInput";
import Checkbox from "../../../utils/checkboxs/Checkbox";
import ValidateField from "../../../utils/validations/ValidateField";
import Button from "@material-ui/core/Button";
import { disableFieldEdit as _disableFieldEdit } from "../../../actions/toolbarActions";
import { createField as _createField, deleteField as _deleteField, deleteNewField as _deleteNewField, updateField as _updateField } from '../../../actions/formActions';
import { connect } from "react-redux";
import SearchableSelect from "../../../utils/selects/SearchableSelect";
import MultiSelect from "../../../utils/selects/MultiSelect";
import { InputLabel } from '@material-ui/core';
import RichTextEditor from '../../../utils/rich-text-editor';
import { Scrollbars } from 'react-custom-scrollbars';
import ConditionalLogic from '../../../utils/conditional-logic';
import { getHeight } from '../../../utils/helpers';
import { processLocalFields } from './utils/helpers';
import FieldRenderer from './utils/FieldRenderer';
import axios from "axios";
import { selectFieldsConfigs } from './utils/selectFieldConfigs';
var basicTabTitle = {
  en: 'Basic Settings',
  ar: 'الإعدادات الأساسية'
};
var advanceTabTitle = {
  en: 'Advance Settings',
  ar: 'إعدادات متقدمة'
};
var machineNameLabel = {
  en: 'Machine Name/Field ID',
  ar: 'إسم الألة'
};
var visibilityLabel = {
  en: 'Visibility to Employee',
  ar: 'الرؤية للموظف'
};
var cancelLabel = {
  en: 'Cancel',
  ar: 'إلغاء'
};
var saveLabel = {
  en: 'Save',
  ar: 'حفظ'
};
var fileTypeLabel = {
  en: 'Supported File Types',
  ar: 'أنواع الملفات المدعومة'
};
var allowMultpleFilesLabel = {
  en: 'Allow Uploading Multiple Files',
  ar: 'تسمح بتحميل ملفات متعددة'
};
var visibleLabel = {
  en: 'Visible',
  ar: 'مرئي'
};
var hiddenLabel = {
  en: 'Hidden',
  ar: 'مختفي'
};
var supportedFileTypes = [{
  label: 'Images',
  value: 'images'
}, {
  label: 'PDF',
  value: 'pdf'
}, {
  label: 'Word Document',
  value: 'word'
}, {
  label: 'Video',
  value: 'video'
}, {
  label: 'Excel Sheet',
  value: 'excel'
}, {
  label: 'Presentation',
  value: 'presentation'
}];

var Select = /*#__PURE__*/function (_React$Component) {
  _inheritsLoose(Select, _React$Component);

  function Select(props) {
    var _this;

    _this = _React$Component.call(this, props) || this;

    _defineProperty(_assertThisInitialized(_this), "handleTabChange", function (e, newValue) {
      _this.setState({
        activeTab: newValue
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleDataChange", function (val, name) {
      var _this$setState;

      _this.setState((_this$setState = {}, _this$setState[name] = val, _this$setState.errors = {}, _this$setState));
    });

    _defineProperty(_assertThisInitialized(_this), "saveField", function () {
      _this.setState(_extends({}, _this.state, {
        isSaving: true
      }));

      var _this$state = _this.state,
          name = _this$state.name,
          machineName = _this$state.machineName,
          order = _this$state.order,
          conditionalLogic = _this$state.conditionalLogic,
          isRequired = _this$state.isRequired,
          placeholder = _this$state.placeholder,
          helpText = _this$state.helpText,
          subType = _this$state.subType,
          visibility = _this$state.visibility,
          uuid = _this$state.uuid,
          type = _this$state.type,
          isMultiple = _this$state.isMultiple,
          supportedFiles = _this$state.supportedFiles,
          parentId = _this$state.parentId;
      var newField = {
        name: name,
        machineName: machineName,
        order: order,
        uuid: uuid,
        type: type,
        parentId: parentId,
        config: {
          conditionalLogic: conditionalLogic,
          isConditionalEnabled: !!conditionalLogic.conditions.length,
          isRequired: isRequired,
          placeholder: placeholder,
          helpText: helpText,
          subType: subType,
          visibility: visibility,
          isMultiple: isMultiple,
          supportedFiles: supportedFiles
        }
      };
      var data = {
        field: newField
      };
      newField.locals = processLocalFields(_this.props.locals, _this.state);
      data.locals = processLocalFields(_this.props.locals, _this.state);
      ValidateField(newField, null, _this.props.currentLang).then( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
        return _regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _this.props.updateField(newField);

                _context.next = 3;
                return axios.post(_this.props.predefinedEndpoint + "/form/field/" + _this.props.formId, data);

              case 3:
                _this.props.disableFieldEdit();

                _this.setState(_extends({}, _this.state, {
                  isSaving: false
                }));

              case 5:
              case "end":
                return _context.stop();
            }
          }
        }, _callee);
      })))["catch"](function (errors) {
        var keys = Object.keys(errors);

        if (keys[0] === 'machineName' || keys[0] === 'conditionalLogic') {
          _this.handleTabChange({}, 'advance');
        } else {
          _this.handleTabChange({}, 'basic');
        }

        _this.setState({
          errors: errors,
          isSaving: false
        });
      });
    });

    _defineProperty(_assertThisInitialized(_this), "cancelEdit", function () {
      _this.props.deleteNewField();

      _this.props.disableFieldEdit();
    });

    _defineProperty(_assertThisInitialized(_this), "updateChoices", function (choices) {
      _this.setState({
        choices: choices
      });
    });

    _defineProperty(_assertThisInitialized(_this), "renderTabFields", function () {
      if (_this.state.activeTab === 'basic') {
        return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(FieldRenderer, _extends({}, _this.state, {
          locals: _this.props.locals,
          fieldConfigs: selectFieldsConfigs,
          handleDataChange: _this.handleDataChange
        })), /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4"
        }, /*#__PURE__*/React.createElement(MultiSelect, {
          label: supportedFileTypes[_this.props.currentLang],
          options: supportedFileTypes,
          value: _this.state.supportedFiles,
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value, 'supportedFiles');
          }
        })), /*#__PURE__*/React.createElement(Checkbox, {
          checked: _this.state.isMultiple,
          handleChange: function handleChange(val) {
            return _this.handleDataChange(val, 'isMultiple');
          },
          label: allowMultpleFilesLabel[_this.props.currentLang]
        }));
      } else {
        return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4"
        }, /*#__PURE__*/React.createElement(TextInput, {
          value: _this.state.machineName,
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value, 'machineName');
          },
          label: machineNameLabel[_this.props.currentLang],
          required: true,
          autoFocus: true,
          error: _this.state.errors.machineName
        })), /*#__PURE__*/React.createElement("div", {
          className: "ahfb-mb-4"
        }, /*#__PURE__*/React.createElement(SearchableSelect, {
          options: [{
            label: visibleLabel[_this.props.currentLang],
            value: 'visible'
          }, {
            label: hiddenLabel[_this.props.currentLang],
            value: 'hidden'
          }],
          label: visibilityLabel[_this.props.currentLang],
          value: _this.state.visibility ? 'visible' : 'hidden',
          handleChange: function handleChange(e) {
            return _this.handleDataChange(e.target.value === 'visible', 'visibility');
          }
        })), /*#__PURE__*/React.createElement(ConditionalLogic, {
          predefined: _this.props.predefined,
          conditionalLogic: _this.state.conditionalLogic,
          isConditionalEnabled: _this.state.isConditionalEnabled,
          handleChange: _this.handleDataChange,
          errors: _this.state.errors.conditionalLogic ? _this.state.errors.conditionalLogic : []
        }));
      }
    });

    var _choices = [{
      name: 'Choice 1',
      value: 1
    }, {
      name: 'Choice 2',
      value: 2
    }, {
      name: 'Choice 3',
      value: 3
    }];
    _this.state = _extends({
      choices: _choices,
      activeTab: 'basic',
      errors: {},
      uuid: props.data.uuid,
      name: props.data.name,
      type: props.data.type,
      order: props.data.order,
      parentId: props.data.parentId,
      machineName: props.data.machineName,
      isSaving: false
    }, props.data.config);
    return _this;
  }

  var _proto = Select.prototype;

  _proto.componentWillReceiveProps = function componentWillReceiveProps(nextProps) {
    if (nextProps.data.uuid !== this.state.uuid) {
      var choices = [{
        name: 'Choice 1',
        value: 1
      }, {
        name: 'Choice 2',
        value: 2
      }, {
        name: 'Choice 3',
        value: 3
      }];
      this.setState(_extends({
        choices: choices,
        activeTab: 'basic',
        errors: {},
        uuid: nextProps.data.uuid,
        name: nextProps.data.name,
        type: nextProps.data.type,
        order: nextProps.data.order,
        parentId: nextProps.data.parentId,
        machineName: nextProps.data.machineName,
        isSaving: false
      }, nextProps.data.config));
    }
  };

  _proto.render = function render() {
    return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(SimpleTabs, {
      value: this.state.activeTab,
      handleChange: this.handleTabChange,
      options: [{
        label: basicTabTitle[this.props.currentLang],
        value: 'basic'
      }, {
        label: advanceTabTitle[this.props.currentLang],
        value: 'advance'
      }]
    }), /*#__PURE__*/React.createElement(Scrollbars, {
      style: {
        height: getHeight(true, true)
      },
      autoHide: true
    }, /*#__PURE__*/React.createElement("div", {
      className: "ahfb-p-3 ahfb-my-3"
    }, this.renderTabFields(), /*#__PURE__*/React.createElement("div", {
      className: "ahfb-width-full ahfb-text-right"
    }, /*#__PURE__*/React.createElement(Button, {
      variant: "outlined",
      className: "ahfb-mr-2",
      onClick: this.cancelEdit
    }, cancelLabel[this.props.currentLang]), /*#__PURE__*/React.createElement(Button, {
      variant: "contained",
      disableElevation: true,
      disabled: this.state.isSaving,
      onClick: this.saveField
    }, saveLabel[this.props.currentLang])))));
  };

  return Select;
}(React.Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    operation: state.toolbar.operation,
    predefined: state.form.predefined,
    locals: state.form.locals,
    formId: state.form.formId,
    predefinedEndpoint: state.form.predefinedEndpoint,
    currentLang: state.form.currentLang
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    disableFieldEdit: function disableFieldEdit() {
      return dispatch(_disableFieldEdit());
    },
    deleteNewField: function deleteNewField() {
      return dispatch(_deleteNewField());
    },
    createField: function createField(data) {
      return dispatch(_createField(data));
    },
    updateField: function updateField(data) {
      return dispatch(_updateField(data));
    },
    deleteField: function deleteField(id) {
      return dispatch(_deleteField(id));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(Select);
